library(tidyverse)
library(tidymodels)
library(caret)
library(SSLR)

data(wine)

set.seed(1)
train.index <- createDataPartition(wine$Wine, p = .7, list = FALSE)
train <- wine[ train.index,]
test  <- wine[-train.index,]

cls <- which(colnames(wine) == "Wine")

#% LABELED
labeled.index <- createDataPartition(wine$Wine, p = .2, list = FALSE)
train[-labeled.index,cls] <- NA

#We need a model with probability predictions from parsnip
#https://tidymodels.github.io/parsnip/articles/articles/Models.html
#It should be with mode = classification

#For example, with Random Forest
rf <-  rand_forest(trees = 100, mode = "classification") %>%
  set_engine("randomForest")


m <- coBC(learner = rf,N = 3,
          perc.full = 0.7,
          u = 100,
          max.iter = 50) %>% fit(Wine ~ ., data = train)
#m <- coBC(learner = rf) %>% fit_xy(x = train[,-cls], y = train$Wine)

#predictions <- predict(m,test[,-cls])

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#Another example, with Boost Tree
bt <-  boost_tree(trees = 100, mode = "classification") %>%
  set_engine("xgboost")

m <- coBC(learner = bt,N = 3,
                  perc.full = 0.7,
                  u = 100,
                  max.iter = 50) %>% fit(Wine ~ ., data = train)
#m <- coBC(learner = bt) %>% fit_xy(x = train[,-cls], y = train$Wine)


#predictions <- predict(m,test[,-cls])

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#With KNN
knn <-  nearest_neighbor(neighbors = 11, mode = "classification") %>%
  set_engine("kknn")


m <- coBC(learner = knn,N = 3,
          perc.full = 0.7,
          u = 100,
          max.iter = 50) %>% fit(Wine ~ ., data = train)


#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#With decision tree from rpart package
dt <-  decision_tree(mode = "classification", tree_depth = 2) %>%
  set_engine("rpart")


m <- coBC(learner = dt,N = 10,
          perc.full = 0.6) %>% fit(Wine ~ ., data = train)

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)



#Single Layer Neural Network

nn <- mlp(mode = "classification",hidden_units = 10, dropout = 0.30) %>%
  set_engine("nnet")


m <- coBC(learner = nn,N = 5,
          perc.full = 0.6) %>% fit(Wine ~ ., data = train)


#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)
