library(tidyverse)
library(caret)
library(SSLR)
library(tidymodels)

#PARALLEL
library(doParallel)

cores <- 2

cl <- NULL
if(cores > 1){
  cl <- parallel::makeCluster(cores)
  doParallel::registerDoParallel(cl)
}


data(wine)

set.seed(1)
train.index <- createDataPartition(wine$Wine, p = .7, list = FALSE)
train <- wine[ train.index,]
test  <- wine[-train.index,]

cls <- which(colnames(wine) == "Wine")

#% LABELED
labeled.index <- createDataPartition(wine$Wine, p = .2, list = FALSE)
train[-labeled.index,cls] <- NA


m <- SSLRRandomForest(trees = 20,  w = 0.3) %>% fit(Wine ~ ., data = train)

#m <- sSSLRDecisionTree() %>% fit_xy(x = train[,-cls], y = train$Wine)

#predictions <- predict(m,test)

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


if(cores > 1)
stopCluster(cl)
