library(tidyverse)
library(tidymodels)
library(caret)
library(SSLR)

data(wine)

set.seed(1)
train.index <- createDataPartition(wine$Wine, p = .7, list = FALSE)
train <- wine[ train.index,]
test  <- wine[-train.index,]

cls <- which(colnames(wine) == "Wine")

#% LABELED
labeled.index <- createDataPartition(train$Wine, p = .2, list = FALSE)
train[-labeled.index,cls] <- NA

#We need a model with probability predictions from parsnip
#https://tidymodels.github.io/parsnip/articles/articles/Models.html
#It should be with mode = classification

#For example, with Random Forest
rf <-  rand_forest(trees = 100, mode = "classification") %>%
  set_engine("randomForest")


m <- selfTraining(learner = rf,max.iter = 50,
                  perc.full = 0.7,
                  thr.conf = 0.5) %>% fit(Wine ~ ., data = train)
#m <- selfTraining(learner = rf) %>% fit_xy(x = train[,-cls], y = train$Wine)

#predictions <- predict(m,test[,-cls])

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#Another example, with Boost Tree
bt <-  boost_tree(trees = 100, mode = "classification") %>%
  set_engine("xgboost")

m <- selfTraining(learner = bt,max.iter = 50,
                  perc.full = 0.7,
                  thr.conf = 0.5) %>% fit(Wine ~ ., data = train)
#m <- selfTraining(learner = bt) %>% fit_xy(x = train[,-cls], y = train$Wine)


#predictions <- predict(m,test[,-cls])

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)



#With KNN
knn <-  nearest_neighbor(neighbors = 11, mode = "classification") %>%
  set_engine("kknn")

m <- selfTraining(learner = knn) %>% fit(Wine ~ ., data = train)

#predictions <- predict(m,test[,-cls])

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#With decision tree from rpart package
dt <-  decision_tree(mode = "classification", tree_depth = 2) %>%
  set_engine("rpart")

m <- selfTraining(learner = dt) %>% fit(Wine ~ ., data = train)

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)


#Single Layer Neural Network

nn <- mlp(mode = "classification", penalty = 0.01) %>%
  set_engine("nnet")

m <- selfTraining(learner = nn) %>% fit(Wine ~ ., data = train)

#Accuracy
predict(m,test) %>%
  bind_cols(test) %>%
  metrics(truth = "Wine", estimate = .pred_class)
